use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Book
CookieJar
Dan
David
Golden
HTTP
Javascript
LWP
RFC's
dagolden
grinnz
hostonly
httponly
jdv
jvolkening
lib
xdg
